==> sale-3.5.3.jar: revenue/sqls/revenue/bill/openSellelent.sql <==
select id,
       f_userinfo_id,
       f_user_name,
       f_address,
       f_pregas,
       f_preamount,
       f_collection,
       f_type,
       f_bill_style,
       f_state,
       f_operate_date,
       f_orgid,
       f_payment,
       f_userinfo_code,
       f_bill_null
from (select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   A.f_user_name,
                   A.f_address,
                   A.f_pregas,
                   A.f_preamount,
                   A.f_collection,
                   A.f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and D.f_bill_state != '开票失败' and D.f_bill_state != '冲正' and
                            D.f_bill_state != '撤销' then '是'
                       else '否' end f_bill_null
            from t_sellinggas A
                left join (select f_userinfo_id b_userinfo_id, f_userinfo_code from t_userinfo) B
            on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join (select f_bill_state, id from t_eticket) D on C.f_eticket_id = D.id) aa
      where {condition}
      union all
      select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   A.f_user_name,
                   A.f_address,
                   0                 f_pregas,
                   0                 f_preamount,
                   A.f_collection,
                   '其他收费'        f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and D.f_bill_state != '开票失败' and D.f_bill_state != '冲正' and
                            D.f_bill_state != '撤销' then '是'
                       else '否' end f_bill_null
            from t_othercharge A
                left join (select f_userinfo_id b_userinfo_id, f_userinfo_code from t_userinfo) B
            on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join (select f_bill_state, id from t_eticket) D on C.f_eticket_id = D.id) aa
      where {condition}
      union all
      --补卡费
      select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   B.f_user_name,
                   D.f_address,
                   1                 f_pregas,
                   0                 f_preamount,
                   A.f_cardfees      f_collection,
                   '补卡费'          f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and E.f_bill_state != '开票失败' and E.f_bill_state != '冲正' and
                            E.f_bill_state != '撤销' then '是'
                       else '否' end f_bill_null
            from t_fillcard A

                left join (select f_userinfo_id b_userinfo_id, f_user_name, f_userinfo_code from t_userinfo) B
            on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join t_user_address D on cast(A.f_userinfo_id as varchar) = cast(D.f_userinfo_id as varchar)
                left join (select f_bill_state, id from t_eticket) E on C.f_eticket_id = E.id
            where f_cardfees > 0) aa
      where {condition}
      union all
      --换表费
      select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   B.f_user_name,
                   D.f_address,
                   1                   f_pregas,
                   A.f_changemeter_fee f_preamount,
                   A.f_changemeter_fee f_collection,
                   '换表费'            f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and E.f_bill_state != '开票失败' and E.f_bill_state != '冲正' and
                            E.f_bill_state != '撤销' then '是'
                       else
                           '否' end    f_bill_null
            from t_changetables A
                left join (select f_userinfo_id b_userinfo_id, f_userinfo_code, f_user_name from t_userinfo) B
            on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join (select f_address, f_userinfo_id from t_user_address) D
                on A.f_userinfo_id = D.f_userinfo_id
                left join (select f_bill_state, id from t_eticket) E on C.f_eticket_id = E.id
            where A.f_changemeter_fee != 0.00) aa
      where {condition}) t
order by f_operate_date desc

==> sale-3.7.1.jar: revenue/sqls/revenue/bill/openSellelent.sql <==
select id,
       f_userinfo_id,
       f_user_name,
       f_address,
       f_pregas,
       f_preamount,
       f_collection,
       f_type,
       f_bill_style,
       f_state,
       f_operate_date,
       f_orgid,
       f_payment,
       f_userinfo_code,
       f_bill_null
from (select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   A.f_user_name,
                   A.f_address,
                   A.f_pregas,
                   A.f_preamount,
                   A.f_collection,
                   A.f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and ( D.f_bill_state != '开票失败' and D.f_total_money > 0) and D.f_bill_state != '冲正' and  D.f_bill_state != '撤销' then '是'
                       else '否' end f_bill_null
            from t_sellinggas A
                left join (select f_userinfo_id b_userinfo_id, f_userinfo_code from t_userinfo) B  on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join (select f_bill_state,f_total_money, id from t_eticket) D on C.f_eticket_id = D.id) aa
      where {condition}
      union all
      select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   A.f_user_name,
                   A.f_address,
                   0                 f_pregas,
                   0                 f_preamount,
                   A.f_collection,
                   '其他收费'        f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and ( D.f_bill_state != '开票失败' and D.f_total_money > 0) and D.f_bill_state != '冲正' and
                            D.f_bill_state != '撤销' then '是'
                       else '否' end f_bill_null
            from t_othercharge A
                left join (select f_userinfo_id b_userinfo_id, f_userinfo_code from t_userinfo) B on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join (select f_bill_state, id, f_total_money from t_eticket) D on C.f_eticket_id = D.id) aa
      where {condition}
      union all
      --补卡费
      select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   B.f_user_name,
                   D.f_address,
                   1                 f_pregas,
                   0                 f_preamount,
                   A.f_cardfees      f_collection,
                   '补卡费'          f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and ( E.f_bill_state != '开票失败' and E.f_total_money > 0) and E.f_bill_state != '冲正' and
                            E.f_bill_state != '撤销' then '是'
                       else '否' end f_bill_null
            from t_fillcard A

                left join (select f_userinfo_id b_userinfo_id, f_user_name, f_userinfo_code from t_userinfo) B
            on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join t_user_address D on cast(A.f_userinfo_id as varchar) = cast(D.f_userinfo_id as varchar)
                left join (select f_bill_state, id,f_total_money from t_eticket) E on C.f_eticket_id = E.id
            where f_cardfees > 0) aa
      where {condition}
      union all
      --换表费
      select id,
             f_userinfo_id,
             f_user_name,
             f_address,
             f_pregas,
             f_preamount,
             f_collection,
             f_type,
             f_bill_style,
             f_state,
             f_operate_date,
             f_orgid,
             f_payment,
             f_userinfo_code,
             f_bill_null
      from (select A.id,
                   A.f_userinfo_id,
                   B.f_user_name,
                   D.f_address,
                   1                   f_pregas,
                   A.f_changemeter_fee f_preamount,
                   A.f_changemeter_fee f_collection,
                   '换表费'            f_type,
                   A.f_bill_style,
                   A.f_state,
                   A.f_operate_date,
                   A.f_orgid,
                   A.f_payment,
                   B.f_userinfo_code,
                   case
                       when C.f_sell_id is not null and ( E.f_bill_state != '开票失败' and E.f_total_money > 0) and E.f_bill_state != '冲正' and
                            E.f_bill_state != '撤销' then '是'
                       else
                           '否' end f_bill_null
            from t_changetables A
                left join (select f_userinfo_id b_userinfo_id, f_userinfo_code, f_user_name from t_userinfo) B on A.f_userinfo_id = B.b_userinfo_id
                left join t_ticketrelated C on A.id = C.f_sell_id
                left join (select f_address, f_userinfo_id from t_user_address) D  on A.f_userinfo_id = D.f_userinfo_id
                left join (select f_bill_state, id,f_total_money from t_eticket) E on C.f_eticket_id = E.id
            where A.f_changemeter_fee != 0.00) aa
      where {condition} and f_bill_null ='否') t
order by f_operate_date desc
